@@ -26,7 +26,7 @@
 #include <gtkmm/entry.h>
 #include <gtkmm/label.h>
 #include "base_db.h"
-#include "connectionpool.h"
+#include <glom/libglom/connectionpool.h>
 
 class Dialog_Connection
   : public Gtk::Dialog,
@@ -40,11 +40,17 @@ public:
 
   virtual void load_from_document(); //override
 
+  /** Use this to override the data from load_from_document().
+   * For instance, if you want to try to connect to a renamed database.
+   */
+  void set_database_name(const Glib::ustring& name);
+
 protected:
   Gtk::Entry* m_entry_host;
   Gtk::Entry* m_entry_user;
   Gtk::Entry* m_entry_password;
   Gtk::Label* m_label_database;
+  Glib::ustring m_database_name;
 };
 
 #endif //GLOM_DIALOG_CONNECTION_H
