@@ -23,7 +23,7 @@
 
 #include <gtkmm/frame.h>
 #include "bakery/View/View_Composite.h"
-#include "document/document_glom.h"
+#include <glom/libglom/document/document_glom.h>
 
 #include "dialog_glom.h"
 
@@ -36,7 +36,7 @@
 #include "mode_design/dialog_fields.h"
 #include "mode_design/dialog_relationships.h"
 #include "dialog_connection.h"
-#include "utils.h"
+#include <glom/libglom/utils.h>
 
 #include "mode_data/box_data_list_related.h" //only for m_HackToFixLinkerError.
 
