@@ -19,9 +19,9 @@
  */
 
 #include "box_data.h"
-#include "../data_structure/glomconversions.h"
-#include "../utils.h"
-#include "../data_structure/layout/layoutitem_field.h"
+#include <glom/libglom/data_structure/glomconversions.h>
+#include <glom/libglom/utils.h>
+#include <glom/libglom/data_structure/layout/layoutitem_field.h>
 #include "../python_embed/glom_python.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <algorithm> //For std::find()
