@@ -41,13 +41,17 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
 
   refGlade->get_widget("hbox_default_value_simple",  m_pBox_DefaultValueSimple);
 
-  refGlade->get_widget("box_default_value",  m_pBox_DefaultValue);
+  refGlade->get_widget("box_default_value",  m_pBox_ValueTab);
+
+  refGlade->get_widget("radiobutton_userentry",  m_pRadio_UserEntry);
+  refGlade->get_widget("alignment_userentry",  m_pAlignment_UserEntry);
+
   refGlade->get_widget("checkbutton_lookup",  m_pCheck_Lookup);
   refGlade->get_widget("table_lookup",  m_pTable_Lookup);
   refGlade->get_widget_derived("combobox_lookup_relationship",  m_pCombo_LookupRelationship);
   refGlade->get_widget_derived("combobox_lookup_field",  m_pCombo_LookupField);
 
-  refGlade->get_widget("checkbutton_calculate",  m_pCheck_Calculate);
+  refGlade->get_widget("radiobutton_calculate",  m_pRadio_Calculate);
   refGlade->get_widget("alignment_calculate",  m_pAlignment_Calculate);
   refGlade->get_widget("textview_calculate",  m_pTextView_Calculation);
   refGlade->get_widget("button_edit_calculation",  m_pButton_EditCalculation);
@@ -57,7 +61,8 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
   m_pCombo_LookupRelationship->signal_changed().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_combo_lookup_relationship_changed) );
   m_pCheck_Lookup->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_check_lookup_toggled) );
 
-  m_pCheck_Calculate->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_check_calculate_toggled) );
+  m_pRadio_Calculate->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_radio_calculate_toggled) );
+  m_pRadio_UserEntry->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_radio_userentry_toggled) );
   m_pButton_EditCalculation->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_button_edit_calculation) );
 
   //TODO:
@@ -90,7 +95,7 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
 
   on_foreach_connect(*this);
   on_foreach_connect(*m_pBox_DefaultValueSimple);
-  on_foreach_connect(*m_pBox_DefaultValue);
+  on_foreach_connect(*m_pBox_ValueTab);
   on_foreach_connect(*m_box_formatting);
 
   Dialog_Properties::set_modified(false);
@@ -107,7 +112,7 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
 {
   set_blocked();
 
-  m_Field = sharedptr<Field>(field->clone()); //Remember it so we save any details that are not in our UI.
+  m_Field = glom_sharedptr_clone(field); //Remember it so we save any details that are not in our UI.
   m_table_name = table_name;  //Used for lookup combo boxes.
 
   //Set the Widgets from the field info:
@@ -142,7 +147,7 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   //We use a regular DataWidget for the default value, so we can reuse its functionality,
   //but it's not a real field - hence the special title.
   sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-  sharedptr<Field> field_default_value = sharedptr<Field>(m_Field->clone());
+  sharedptr<Field> field_default_value = glom_sharedptr_clone(m_Field);
   field_default_value->set_name("glom_temp_default_value");
   field_default_value->set_title(_("Default Value"));
   layout_item->set_full_field_details(field_default_value);
@@ -167,7 +172,7 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   if(document)
   {
     const Document_Glom::type_vecRelationships vecRelationships = document->get_relationships(table_name);
-    m_pCombo_LookupRelationship->set_relationships(vecRelationships, table_name, document->get_table_title(table_name));
+    m_pCombo_LookupRelationship->set_relationships(vecRelationships);
   }
 
   sharedptr<Relationship> lookup_relationship;
@@ -185,7 +190,11 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
 
   //Calculation:
   const Glib::ustring calculation = field->get_calculation();
-  m_pCheck_Calculate->set_active(!calculation.empty());
+  if(calculation.empty())
+   m_pRadio_UserEntry->set_active();
+  else
+    m_pRadio_Calculate->set_active();
+
   on_check_lookup_toggled();
 
   m_pTextView_Calculation->get_buffer()->set_text(calculation);
@@ -203,7 +212,7 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
 
 sharedptr<Field> Dialog_FieldDefinition::get_field() const
 {
-  sharedptr<Field> field = sharedptr<Field>(m_Field->clone()); //Start with the old details, to preserve anything that is not in our UI.
+  sharedptr<Field> field = glom_sharedptr_clone(m_Field); //Start with the old details, to preserve anything that is not in our UI.
 
   //Get the field info from the widgets:
 
@@ -237,7 +246,7 @@ sharedptr<Field> Dialog_FieldDefinition::get_field() const
 
 
   //Calculation:
-  if(m_pCheck_Calculate)
+  if(m_pRadio_Calculate)
     field->set_calculation(m_pTextView_Calculation->get_buffer()->get_text());
 
   Gnome::Gda::FieldAttributes field_info_copy = fieldInfo;
@@ -267,7 +276,7 @@ void Dialog_FieldDefinition::on_combo_type_changed()
 }
 
 void Dialog_FieldDefinition::enforce_constraints()
-{  
+{
   if(m_pCheck_PrimaryKey->get_active())
   {
     m_pCheck_Unique->set_active(true); //Primary keys must be unique.
@@ -278,16 +287,19 @@ void Dialog_FieldDefinition::enforce_constraints()
 
   if(m_pCheck_Unique->get_active() || m_pCheck_AutoIncrement->get_active())
   {
-    m_pBox_DefaultValue->set_sensitive(false); //Disable all controls on the Notebook page.
+    m_pBox_ValueTab->set_sensitive(false); //Disable all controls on the Notebook page.
     m_pDataWidget_DefaultValueSimple->set_value( Gnome::Gda::Value() ); //Unique fields cannot have default values. //TODO: People will be surprised when they lose information here. We should probably read the text as "" if the widget is disabled.
   }
   else
   {
-    m_pBox_DefaultValue->set_sensitive(true);
+    m_pBox_ValueTab->set_sensitive(true);
   }
 
-  bool enable_calc = m_pCheck_Calculate->get_active();
+  const bool enable_calc = m_pRadio_Calculate->get_active();
   m_pAlignment_Calculate->set_sensitive(enable_calc);
+
+  const bool enable_userentry = m_pRadio_UserEntry->get_active();
+  m_pAlignment_UserEntry->set_sensitive(enable_userentry);
 }
 
 void Dialog_FieldDefinition::on_check_lookup_toggled()
@@ -299,15 +311,24 @@ void Dialog_FieldDefinition::on_check_lookup_toggled()
   enforce_constraints();
 }
 
-void Dialog_FieldDefinition::on_check_calculate_toggled()
+void Dialog_FieldDefinition::on_radio_calculate_toggled()
 {
-  bool enable = m_pCheck_Calculate->get_active();
+  bool enable = m_pRadio_Calculate->get_active();
   m_pAlignment_Calculate->set_sensitive(enable);
 
   //re-disable it if it was not meant to be enabled:
   enforce_constraints();
 }
 
+void Dialog_FieldDefinition::on_radio_userentry_toggled()
+{
+  bool enable = m_pRadio_UserEntry->get_active();
+  m_pAlignment_UserEntry->set_sensitive(enable);
+
+  //re-disable it if it was not meant to be enabled:
+  enforce_constraints();
+}
+
 
 void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
 {
