@@ -21,9 +21,9 @@
 #include <iostream>
 #include "glom_db_treemodel.h"
 
-#include "../../connectionpool.h"
-#include "../../data_structure/glomconversions.h" //For util_build_sql
-#include "../../utils.h"
+#include <glom/libglom/connectionpool.h>
+#include <glom/libglom/data_structure/glomconversions.h> //For util_build_sql
+#include <glom/libglom/utils.h>
 
 
 DbTreeModelRow::DbTreeModelRow()
@@ -239,7 +239,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       }
       */
 
-      return true;
+      return (m_data_model_rows_count > 0); //false is not really a failure, but the caller needs to know whether the foundset found any records.
     }
   }
   else
